@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 
 
 #
@@ -15,7 +16,6 @@
 
 
 module Ascii85
-
   #
   # Encodes the bytes of the given String as Ascii85.
   #
@@ -37,7 +37,6 @@ module Ascii85
   #
   #
   def self.encode(str, wrap_lines = 80)
-
     to_encode = str.to_s
     return '' if to_encode.empty?
 
@@ -59,7 +58,7 @@ module Ascii85
       if tuple == 0
         'z'
       else
-        tmp = ""
+        tmp = String.new
         5.times do
           tmp << ((tuple % 85) + 33).chr
           tuple /= 85
@@ -82,7 +81,6 @@ module Ascii85
     end
 
     # Otherwise we wrap the lines
-
     line_length = [2, wrap_lines.to_i].max
 
     wrapped = []
@@ -122,7 +120,6 @@ module Ascii85
   # encountered.
   #
   def self.decode(str)
-
     input = str.to_s
 
     opening_delim = '<~'
@@ -134,9 +131,9 @@ module Ascii85
     # errors if an especially exotic input encoding is introduced.
     # As of Ruby 1.9.2 all non-dummy encodings work fine though.
     #
-    if opening_delim.respond_to?(:encode!)
-      opening_delim.encode!(input.encoding)
-      closing_delim.encode!(input.encoding)
+    if opening_delim.respond_to?(:encode)
+      opening_delim = opening_delim.encode(input.encoding)
+      closing_delim = closing_delim.encode(input.encoding)
     end
 
     # Get the positions of the opening/closing delimiters. If there is
@@ -153,7 +150,6 @@ module Ascii85
     result = []
 
     input.each_byte do |c|
-
       case c.chr
       when " ", "\t", "\r", "\n", "\f", "\0"
         # Ignore whitespace
@@ -189,7 +185,6 @@ module Ascii85
         raise(Ascii85::DecodingError,
               "Illegal character inside Ascii85: #{c.chr.dump}")
       end
-
     end
 
     # Convert result into a String
@@ -225,5 +220,4 @@ module Ascii85
   #   at least two characters.
   #
   class DecodingError < StandardError; end
-
 end
